
Incorrect or missing charset 
-------

**Description:**

When the browser has to guess the charset according of the content that is presented by 
the application, then this could could lead to XSS injections when guessing wrong.



**Solution:**

Define the charset for each page.

	